#ifndef PACKAGESEARCH_WORKAROUNDS_H
#define PACKAGESEARCH_WORKAROUNDS_H

/*
 * Workarounds for symbol clashes
 */

/*
 * emit is a #define in qt and a method name in sigc++, so you have to include
 * it before qt-anything
 */
//#include <sigc++/sigc++.h>

/*
 * QT makes use of a GC symbol, which is also defined by libgc, that gets
 * included by wibble, that gets included by ept
 */
#define GC QT_GC_WORKAROUND
#include <qwindowdefs.h>
#include <qpainter.h>
#undef GC

#endif
